@@ -2,7 +2,7 @@
 /**
  * Nag external API interface.
  *
- * $Horde: nag/lib/api.php,v 1.100.10.46 2009/09/04 10:38:38 jan Exp $
+ * $Horde: nag/lib/api.php,v 1.100.10.47 2010-05-09 19:00:31 mrubinsk Exp $
  *
  * This file defines Nag's external API interface. Other applications can
  * interact with Nag through this API.
@@ -171,23 +171,6 @@ function _nag_removeUserData($user)
         }
     }
 
-    /* Now delete history as well. */
-    $history = &Horde_History::singleton();
-    if (method_exists($history, 'removeByParent')) {
-        $histories = $history->removeByParent('nag:' . $user);
-    } else {
-        /* Remove entries 100 at a time. */
-        $all = $history->getByTimestamp('>', 0, array(), 'nag:' . $user);
-        if (is_a($all, 'PEAR_Error')) {
-            Horde::logMessage($all, __FILE__, __LINE__, PEAR_LOG_ERR);
-        } else {
-            $all = array_keys($all);
-            while (count($d = array_splice($all, 0, 100)) > 0) {
-                $history->removebyNames($d);
-            }
-        }
-    }
-
     /* ...and finally, delete the actual share */
     if (!empty($share)) {
         $result = $GLOBALS['nag_shares']->removeShare($share);
