@@ -1,10 +1,10 @@
 <?php
 /**
- * $Horde: nag/search.php,v 1.17.8.4 2007/01/02 13:55:12 jan Exp $
+ * $Horde: nag/search.php,v 1.17.8.7 2009-01-06 15:25:04 jan Exp $
  *
- * Copyright 2001-2007 Jon Parise <jon@horde.org>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  */
 
@@ -13,7 +13,9 @@ require_once NAG_BASE . '/lib/base.php';
 
 $title = _("Search");
 $notification->push('document.search.search_pattern.focus()', 'javascript');
+Horde::addScriptFile('prototype.js', 'nag', true);
 require NAG_TEMPLATES . '/common-header.inc';
 require NAG_TEMPLATES . '/menu.inc';
 require NAG_TEMPLATES . '/search/search.inc';
+require NAG_TEMPLATES . '/panel.inc';
 require $registry->get('templates', 'horde') . '/common-footer.inc';
